@@ -1,17 +1,35 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from __future__ import (division, print_function, absolute_import,
-                        unicode_literals)
+from __future__ import division, print_function
 
-__all__ = ["sample_ball", "MH_proposal_axisaligned", "MPIPool"]
+__all__ = ["sample_ball", "deprecated", "deprecation_warning"]
 
+import warnings
+from functools import wraps
 
 import numpy as np
 
-from .mpi_pool import MPIPool
+
+def deprecation_warning(msg):
+    warnings.warn(msg, category=DeprecationWarning, stacklevel=2)
 
 
+def deprecated(alternate):
+    def wrapper(func, alternate=alternate):
+        msg = "'{0}' is deprecated.".format(func.__name__)
+        if alternate is not None:
+            msg += " Use '{0}' instead.".format(alternate)
+
+        @wraps(func)
+        def f(*args, **kwargs):
+            deprecation_warning(msg)
+            return func(*args, **kwargs)
+        return f
+
+    return wrapper
+
+
+@deprecated(None)
 def sample_ball(p0, std, size=1):
     """
     Produce a ball of walkers around an initial parameter value.
@@ -26,6 +44,7 @@ def sample_ball(p0, std, size=1):
                       for i in range(size)])
 
 
+@deprecated(None)
 def sample_ellipsoid(p0, covmat, size=1):
     """
     Produce an ellipsoid of walkers around an initial parameter value,
@@ -41,19 +60,3 @@ def sample_ellipsoid(p0, covmat, size=1):
     return np.random.multivariate_normal(np.atleast_1d(p0),
                                          np.atleast_2d(covmat),
                                          size=size)
-
-
-class MH_proposal_axisaligned(object):
-    """
-    A Metropolis-Hastings proposal, with axis-aligned Gaussian steps,
-    for convenient use as the ``mh_proposal`` option to
-    :func:`EnsembleSampler.sample` .
-
-    """
-    def __init__(self, stdev):
-        self.stdev = stdev
-
-    def __call__(self, X):
-        (nw, npar) = X.shape
-        assert(len(self.stdev) == npar)
-        return X + self.stdev * np.random.normal(size=X.shape)
